@@ -5,24 +5,25 @@ from dbt.adapters.base.relation import BaseRelation, Policy
 
 
 @dataclass
-class ClickhouseQuotePolicy(Policy):
+class ClickHouseQuotePolicy(Policy):
     database: bool = False
     schema: bool = False
     identifier: bool = False
 
 
 @dataclass
-class ClickhouseIncludePolicy(Policy):
+class ClickHouseIncludePolicy(Policy):
     database: bool = False
     schema: bool = True
     identifier: bool = True
 
 
 @dataclass(frozen=True, eq=False, repr=False)
-class ClickhouseRelation(BaseRelation):
-    quote_policy: ClickhouseQuotePolicy = ClickhouseQuotePolicy()
-    include_policy: ClickhouseIncludePolicy = ClickhouseIncludePolicy()
-    quote_character: str = ""
+class ClickHouseRelation(BaseRelation):
+    quote_policy: ClickHouseQuotePolicy = ClickHouseQuotePolicy()
+    include_policy: ClickHouseIncludePolicy = ClickHouseIncludePolicy()
+    quote_character: str = ''
+    can_exchange: bool = False
 
     def __post_init__(self):
         if self.database != self.schema and self.database:
